@@ -20,7 +20,7 @@ my @credentials=(
                './credentials.pl', 
              ); 
 
-our $VERSION=0.098; 
+our $VERSION=0.099; 
 ######### code for multiiple -n x arguments treat as single joined with |. Not handled with getopts. 
 $opt{n}=[]; 
 for my $i (0..$#ARGV)
@@ -44,7 +44,7 @@ $opt{n} or delete $opt{n};
 $opt{a}=1; 
 #########
 
-getopts('a:c:eotf:Nhn:s:SO:g:', \%opt) or help("Aborted! -h for help "); 
+getopts('a:c:eotf:FNhn:s:SO:g:', \%opt) or help("Aborted! -h for help "); 
 
 my $ig; 
 # IG Credentials needed. 
@@ -98,9 +98,9 @@ else
      sub cred
      { 
         return  { 
-                   username='',      # Your ig username 
-                   password=>'',  # Your ig password
-                   apikey=>'' ,   # Your ig apikey
+                   username=>'',      # Your ig username 
+                   password=>'',      # Your ig password
+                   apikey=>'' ,       # Your ig apikey
                 } 
      }; 
      1; 
@@ -241,7 +241,6 @@ else
 } 
 # $ig->sorter(['-atrisk'],$p); 
 
-printf "%d Positions\n",@$p+0 if (!$opt{S}); 
 
 if ($opt{o})
 {
@@ -268,17 +267,27 @@ my @format=(
            #4  
            "%-41sinstrumentName %screatedDateUTC %+6.2fsize %-9.2flevel ".
            "%-9.2fbid £%-8.2fprofit %5.1fprofitpc%% £%10.2fatrisk\n", 
+
+           #5 
+           "%-41sinstrumentName %6sheld %-6.1fdailyp %+4.2fsize %-9.2flevel  %-41sinstrumentName %screatedDateUTC %+6.2fsize %-9.2flevel\n", 
      
           ); 
 my $format; 
 
 if (defined($opt{f}))
 { 
-   die "option fn out of range (0..".(@format+0).")"  if ($opt{f}<1 || $opt{f}>@format+0); 
-   $format=$format[$opt{f}-1]; 
-   if ($opt{f}>1) 
+   if ($opt{f}=~m/^[0-9]+$/)
    { 
-     $ig->uds(''); 
+      die "option fn out of range (0..".(@format+0).")"  if ($opt{f}<1 || $opt{f}>@format+0); 
+      $format=$format[$opt{f}-1]; 
+      if ($opt{f}>1) 
+      { 
+        $ig->uds(''); 
+      } 
+   } 
+   else
+   { 
+     $format=$opt{f}."\n"; 
    } 
 } 
 else
@@ -286,6 +295,9 @@ else
     $format=$format[0]; 
 } 
 
+$opt{F} and print $format and exit; 
+printf "%d Positions\n",@$p+0 if (!$opt{S}); 
+
 my $titles=["Epic", 'Name','Size','Open','Latest','P/L','P/L','Value']; 
 $titles=undef; 
 
@@ -385,7 +397,8 @@ The default display is decending order of percent profit.  Various formats are p
 -a n aggregate 1 (default) , nonaggregate 0 = show individual holdings
 -e explain where credentials for login are coming from, then exit. 
 -o Send output to an autogenerated, time based file. 
--f n use one of the inbuilt formats 1 to 5. 
+-f n use one of the inbuilt formats 1 to 5. Or provide the format to use. 
+-F print the current format and exit .  
 -h this message and exit
 -n xxx use xxx as a pattern in name to grep for particular positions. Can use | for or. (Must be quoted) 
    multipl -n allowed. 
@@ -411,7 +424,7 @@ The default display is decending order of percent profit.  Various formats are p
    2020/11/05 means the days are equal while 2020/11 means amy time that month 
 "; 
 exit 1 if (defined $mess and length($mess)>1); 
-print "A complete list of fields in a position isi as follows. Some of these 
+print "A complete list of fields in a position is as follows. Some of these 
 are IG things, and some are calculated: 
 
     bid
@@ -420,14 +433,14 @@ are IG things, and some are calculated:
     createdDate
     createdDateUTC
     currency
-    dailyp
+    dailyp                profit in % per day averaged over holding time 
     dealId
     dealReference
     delayTime
     direction
     epic
     expiry
-    held
+    held                  days held 
     high
     instrumentName
     instrumentType
